==> MuSE-0.2.tar.gz: MuSE-0.2/muse.cpp <==
#include <iostream.h>
#include <getopt.h>
#include <string.h>

#include "jmixer.h"
#include "netlistener.h"
#include "libsync/synchronous.h"

#define LISTENPORT 6969

/* ------------------- command line stuff --------------------------- */

char *version =
"MuSE v0.2.0 - (c)2000 Denis Roio aka jaromil\n";

char *help =
"Usage: muse [options]\n\n"
"Generic options\n"
"-h --help\tthis help\n"
"-v --version\tversion information\n"
"-d --debug\tturn debug informations on\n"
"-l --playlist\tuse filename as playlist (default ./playlist)\n"
"\n"
"Mp3 encoding and X-Audiocast streaming options\n"
"if not used output defaults to soundcard /dev/dsp\n"
"-i --icecast\tstream mixed output to this ip\n"
"-p --port\ton this port\n"
"-a --passwd\tauthenticate with this passwd\n"
"-m --mount\tput the stream on this mountpoint\n"
"-b --bitrate\tencode at this bitrate (expressed in KBps)\n"
/* "-q --quality\tencode with this quality (1 is the best)\n" */
"\n"
"--\n"
"for any further information refer to http://muse.dyne.org\n";

static const struct option long_options[] = {
  { "help", no_argument, NULL, 'h' },
  { "version", no_argument, NULL, 'v' },
  { "debug", no_argument, NULL, 'd' },
  { "playlist", required_argument, NULL, 'l' },
  { "icecast", required_argument, NULL, 'i' },
  { "port", required_argument, NULL, 'p' } ,
  { "passwd", required_argument, NULL, 'a' },
  { "mount", required_argument, NULL, 'm' },
  { "bitrate", required_argument, NULL, 'b' },
  /*  { "quality", required_argument, NULL, 'q' }, */
  { 0, 0, 0, 0 }
};

char *short_options = "hvdl:i:p:a:m:b:";

/* misc settings */
bool debug = false;
char playlist[256];

/* xaudiocast & encoder settings */
int use_broadcast;
char broadcast_ip[16];
int broadcast_port;
char broadcast_passwd[16];
char broadcast_mountpoint[16];
int encoder_bps;
/* int encoder_quality; */

void take_args(int argc, char **argv) {
  int res;

  use_broadcast = 0;
  strcpy(playlist,"./playlist");

  do {
    res = getopt_long(argc, argv, short_options, long_options, NULL);

    switch(res) {
    case 'h':
      fprintf(stderr,"%s",version);
      fprintf(stderr,"%s",help);
      exit(0);
      break;
    case 'v':
      fprintf(stderr,"%s",version);
      exit(0);
      break;
    case 'd':
      debug = true;
      break;
    case 'l':
      strncpy(playlist,optarg,256);
      break;
    case 'i':
      strncpy(broadcast_ip, optarg, 16);
      use_broadcast++;
      break;
    case 'p':
      broadcast_port = atoi(optarg);
      use_broadcast++;
      break;
    case 'a':
      strncpy(broadcast_passwd,optarg,16);
      use_broadcast++;
      break;
    case 'm':
      strncpy(broadcast_mountpoint,optarg,16);
      use_broadcast++;
      break;
    case 'b':
      encoder_bps = atoi(optarg);
      use_broadcast++;
      break;
      /*    case 'q':
	    encoder_quality = atoi(optarg);
	    break;
      */
    }
  } while(res > 0);

  if ((use_broadcast>0)&&(use_broadcast<4)) {
    fprintf(stderr,"Please supply all the data required about the broadcast server\n");
    exit(1);
  }

}

int main(int argc, char **argv) {

  take_args(argc, argv);

  /* change those for having the stderr flodded by
     the libsync threaded kernel debugging messages */
  LTI::Kernel::trace = false;
  LTI::Kernel::debug = false;

  fprintf(stderr,"%sstarting engine...\n",version);

  Stream_mixer *mix = new Stream_mixer();

  if(use_broadcast) {

    /* that's dirty, just for trying soundcard input
       then it need to be differentiated the opening of the soundcard device
       if fullduplex or just reading or just writing */
    if(!mix->open_soundcard()) {
      fprintf(stderr,"exiting.\n");
      exit(1);
    }

    if(!mix->open_icecast(broadcast_ip,broadcast_port,broadcast_passwd,broadcast_mountpoint, encoder_bps)) {
      fprintf(stderr,"exiting.\n");
      exit(1);
    }

  } else {
    if(!mix->open_soundcard()) {
      fprintf(stderr,"exiting.\n");
      exit(1);
    }
  }

  mix->set_playlist(playlist);

  mix->start();

  Net_listener *net = new Net_listener(LISTENPORT,mix);

  net->start();

  while(1) {
    mix->join();
    net->join();
  }

  exit(0);
}

==> MuSE-0.3.tar.gz: MuSE-0.3/muse.cpp <==
#include <iostream.h>
#include <getopt.h>
#include <string.h>
#include <unistd.h>

#include "generic.h"
#include "jmixer.h"
#include "netlistener.h"
#include "scheduler.h"
#include "libsync/synchronous.h"

/* ------------------- command line stuff --------------------------- */

char *version = "MuSE v0.3.0 - (c)2000 MuSE development team\n";

char *help =
"Usage: muse [options]\n\n"
"Generic options\n"
"-h --help\tthis help\n"
"-v --version\tversion information\n"
"-d --debug\tturn debug informations on\n"
"-D --daemon\tdaemon mode: do not spawn amuse local interface"
"-l --playlist\tuse filename as playlist (default ./playlist)\n"
"\n"
"--\n"
"for any further information refer to http://muse.dyne.org\n";

static const struct option long_options[] = {
  { "help", no_argument, NULL, 'h' },
  { "version", no_argument, NULL, 'v' },
  { "debug", no_argument, NULL, 'd' },
  { "daemon", no_argument, NULL, 'D' },
  { "playlist", required_argument, NULL, 'l' },
  { 0, 0, 0, 0 }
};

char *short_options = "hvdDl:";

/* misc settings */
bool debug = false;
bool daemon_mode = false;
char playlist[256];

void take_args(int argc, char **argv) {
  int res;

  strcpy(playlist,"./playlist");

  do {
    res = getopt_long(argc, argv, short_options, long_options, NULL);

    switch(res) {
    case 'h':
      fprintf(stderr,"%s",version);
      fprintf(stderr,"%s",help);
      exit(0);
      break;
    case 'v':
      fprintf(stderr,"%s",version);
      exit(0);
      break;
    case 'd':
      debug = true;
      break;
    case 'D':
      daemon_mode = true;
      break;
    case 'l':
      strncpy(playlist,optarg,256);
      break;
    }
  } while(res > 0);

}

int main(int argc, char **argv) {

  take_args(argc, argv);

  /* change those for having the stderr flodded by
     the libsync threaded kernel debugging messages */
  LTI::Kernel::trace = false;
  LTI::Kernel::debug = false;

  fprintf(stderr,"%sstarting engine...\n",version);

  Stream_mixer *mix = new Stream_mixer();

  if(!mix->open_soundcard()) {
    fprintf(stderr,"exiting.\n");
    exit(1);
  }

  /* we are still not implementing single channel playlists

     int c;
     for(c=0;c<MAX_CHANNELS;c++)
     mix->set_playlist(c, playlist);
     
     so we put a duplicated memory wasting unique playlist equal for all channels
     looking forward to the next release for the final playlist solution...
  */
  int c;
  for(c=0;c<MAX_CHANNELS;c++)
    mix->mp3ch[c].get_playlist(playlist);

  mix->start();

  Net_listener *net = new Net_listener(LISTENPORT,mix);

  net->start();

  /* spawn tcl/tk interface */
  if(!daemon_mode) {
    pid_t amuse;
    amuse = fork();
    if(!amuse) {
      fprintf(stderr,"Spawning the A-MuSE interface\n");
      execlp("./amuse","amuse",NULL);
      exit(0);
    }
  }

  net->join();
  mix->join();

  fprintf(stderr,"cya!\n");

  exit(0);
}
